==> nextcloud-25.0.7.tgz: nextcloud/apps/dav/l10n/sl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Koledar",
    "To-dos" : "Naloge To-Do",
    "Personal" : "Osebno",
    "{actor} created calendar {calendar}" : "{actor} ustvari koledar {calendar}",
    "You created calendar {calendar}" : "Ustvarite koledar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} izbriše koledar {calendar}",
    "You deleted calendar {calendar}" : "Izbrišete koledar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} posodobi koledar {calendar}",
    "You updated calendar {calendar}" : "Posodobite koledar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} obnovi koledar {calendar}",
    "You restored calendar {calendar}" : "Ustvarite koledar {calendar}",
    "You shared calendar {calendar} as public link" : "Omogočite souporabo koledarja {calendar} z javno povezavo",
    "You removed public link for calendar {calendar}" : "Odstranite javno povezavo koledarja {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} mi omogoči souporabo koledarja {calendar}",
    "You shared calendar {calendar} with {user}" : "Omogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} omogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} mi oneomogoči souporabo koledarja {calendar}",
    "You unshared calendar {calendar} from {user}" : "Onemogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} onemogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} onemogoči souporabo koledarja {calendar} s samim sabo",
    "You shared calendar {calendar} with group {group}" : "Omogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} omogoči souporabo koledarja {calendar} s skupino {group}",
    "You unshared calendar {calendar} from group {group}" : "Onemogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} onemogoči souporabo koledarja {calendar} s skupino {group}",
    "Untitled event" : "Neimenovan dogodek¨",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ustvari dogodek {event} v koledarju {calendar}",
    "You created event {event} in calendar {calendar}" : "Ustvarite dogodek {event} v koledarju {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} izbriše dogodek {event} iz koledarja {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Izbrišete dogodek {event} v koledarju {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} posodobi dogodek {event} v koledarju {calendar}",
    "You updated event {event} in calendar {calendar}" : "Posodobite dogodek {event} v koledarju {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} premakne dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Premaknete dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} obnovi dogodek {event} v koledarju {calendar}",
    "You restored event {event} of calendar {calendar}" : "Obnovite dogodek {event} v koledarju {calendar}",
    "Busy" : "Zasedeno",
    "Calendar, contacts and tasks" : "Koledar, stiki in naloge",
    "A <strong>calendar</strong> was modified" : "V <strong>koledar</strong> je vpisana sprememba",
    "A calendar <strong>event</strong> was modified" : "Spremenjen je <strong>dogodek</strong> v koledarju",
    "Contact birthdays" : "Obletnice stikov",
    "Death of %s" : "%s (obletnica smrti)",
    "Untitled calendar" : "Neimenovan koledar",
    "Calendar:" : "Koledar:",
    "Date:" : "Datum:",
    "Where:" : "Kje:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n leto","%n leti","%n leta","%n let"],
    "_%n month_::_%n months_" : ["%n mesec","%n meseca","%n meseci","%n mesecev"],
    "_%n day_::_%n days_" : ["%n dan","%n dneva","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n ura","%n uri","%n ure","%n ur"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuti","%n minute","%n minut"],
    "%s (in %s)" : "%s (čez %s)",
    "%s (%s ago)" : "%s (%s nazaj)",
    "Calendar: %s" : "Koledar: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Kje: %s",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Cancelled: %1$s" : "Preklicano: %1$s",
    "Re: %1$s" : "Odg: %1$s",
    "Invitation: %1$s" : "Povabilo: %1$s",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Udeleženci:",
    "Title:" : "Naslov:",
    "Time:" : "Čas:",
    "Location:" : "Mesto:",
    "Link:" : "Povezava:",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "More options …" : "Več možnosti ...",
    "More options at %s" : "Več možnosti je na %s",
    "Contacts" : "Stiki",
    "You deleted address book {addressbook}" : "Izbrišete imenik {addressbook}",
    "Could not write file contents" : "Ni mogoče zapisati vsebine datoteke",
    "Could not rename part file to final file" : "Ni mogoče preimenovati delne datoteke v končno ime.",
    "Failed to check file size: %1$s" : "Preverjanje velikosti je spodletelo: %1$s",
    "Could not open file" : "Datoteke ni mogoče odpreti",
    "System is in maintenance mode." : "Sistem je v vzdrževalnem načinu.",
    "Upgrade needed" : "Zahtevana je posodobitev",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Za uporabo CalDAV in CardDAV v okoljih iOS/macOS je treba %s nastaviti za uporabo HTTPS.",
    "Configures a CalDAV account" : "Nastavi račun CalDAV",
    "Configures a CardDAV account" : "Nastavi račun CardDAV",
    "Events" : "Dogodki",
    "Tasks" : "Naloge",
    "Untitled task" : "Neimenovana naloga",
    "Completed on %s" : "Končana %s",
    "Due on %s by %s" : "Poteče %s ob %s",
    "Due on %s" : "Poteče %s",
    "Contacts and groups" : "Stiki in skupine",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Končna točka WebDAV",
    "Availability" : "Razpoložljivost",
    "Time zone:" : "Časovni pas:",
    "to" : "do",
    "Delete slot" : "Izbriši možnost",
    "No working hours set" : "Ni navedenih delovnih ur",
    "Add slot" : "Dodaj možnost",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sunday" : "nedelja",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Samodejno nastavi stanje uporabnika na »Ne moti« in zavračaj prikaz obvestil izven časa razpoložljivosti.",
    "Save" : "Shrani",
    "Failed to load availability" : "Nalaganje seznama razpoložljivih polj je spodletelo",
    "Calendar server" : "Strežnik koledarja",
    "Send invitations to attendees" : "Pošlji povabilo udeležencem",
    "Automatically generate a birthday calendar" : "Samodejno ustvari koledar rojstnih dni",
    "Birthday calendars will be generated by a background job." : "Koledarji rojstnih dni bodo ustvarjeni in posodabljani v ozadju.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "To pomeni, da ne bodo na voljo takoj po omogočanju, ampak šele po krajšem času.",
    "Send notifications for events" : "Pošlji obvestila za dogodke",
    "Notifications are sent via background jobs, so these must occur often enough." : "Obvestila so poslana samodejno z opravili v ozadju, ker pomeni, da se morajo ta izvajati dovolj pogosto.",
    "Enable notifications for events via push" : "Omogoči potisna obvestila za dogodke",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Namestite tudi {calendarappstoreopen}Koledar{linkclose}, ali pa se povežite z {calendardocopen}namiznim oziroma mobilnim usklajevalnikom ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Prepričajte se, da je {emailopen}poštni strežnik{linkclose} pravilno nastavljen.",
    "There was an error updating your attendance status." : "Prišlo je do napake med posodabljanjem vaše udeležbe.",
    "Please contact the organizer directly." : "Z organizatorjem stopite neposredno v stik.",
    "Are you accepting the invitation?" : "Ali želite sprejeti povabilo?",
    "Tentative" : "Začasno",
    "Your attendance was updated successfully." : "Vaša prisotnost je uspešno posodobljena.",
    "Todos" : "Naloge",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ustvari nalogo {todo} v koledarju {calendar}",
    "You created todo {todo} in list {calendar}" : "Ustvarite nalogo {todo} v koledarju {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} izbriše nalogo {todo} iz koledara {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Izbrišete nalogo {todo} iz koledarja {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} posodobi nalogo {todo} v koledarju {calendar}",
    "You updated todo {todo} in list {calendar}" : "Posodobite nalogo {todo} v seznamu {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} razreši nalogo {todo} v koledarju {calendar}",
    "You solved todo {todo} in list {calendar}" : "Razrešite nalogo {todo} v seznamu {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ponovno odpre nalogo {todo} v koledarju {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ponovno odprete nalogo {todo} v seznamu {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Spremenjena je <strong>naloga</strong> koledarja",
    "Invitation canceled" : "Povabilo je preklicano",
    "Invitation updated" : "Povabilo je posodobljeno",
    "Invitation" : "Povabilo"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/dav/l10n/sl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Koledar",
    "To-dos" : "Naloge To-Do",
    "Personal" : "Osebno",
    "{actor} created calendar {calendar}" : "{actor} ustvari koledar {calendar}",
    "You created calendar {calendar}" : "Ustvarite koledar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} izbriše koledar {calendar}",
    "You deleted calendar {calendar}" : "Izbrišete koledar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} posodobi koledar {calendar}",
    "You updated calendar {calendar}" : "Posodobite koledar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} obnovi koledar {calendar}",
    "You restored calendar {calendar}" : "Ustvarite koledar {calendar}",
    "You shared calendar {calendar} as public link" : "Omogočite souporabo koledarja {calendar} z javno povezavo",
    "You removed public link for calendar {calendar}" : "Odstranite javno povezavo koledarja {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} mi omogoči souporabo koledarja {calendar}",
    "You shared calendar {calendar} with {user}" : "Omogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} omogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} mi oneomogoči souporabo koledarja {calendar}",
    "You unshared calendar {calendar} from {user}" : "Onemogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} onemogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} onemogoči souporabo koledarja {calendar} s samim sabo",
    "You shared calendar {calendar} with group {group}" : "Omogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} omogoči souporabo koledarja {calendar} s skupino {group}",
    "You unshared calendar {calendar} from group {group}" : "Onemogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} onemogoči souporabo koledarja {calendar} s skupino {group}",
    "Untitled event" : "Neimenovan dogodek¨",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ustvari dogodek {event} v koledarju {calendar}",
    "You created event {event} in calendar {calendar}" : "Ustvarite dogodek {event} v koledarju {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} izbriše dogodek {event} iz koledarja {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Izbrišete dogodek {event} v koledarju {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} posodobi dogodek {event} v koledarju {calendar}",
    "You updated event {event} in calendar {calendar}" : "Posodobite dogodek {event} v koledarju {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} premakne dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Premaknete dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} obnovi dogodek {event} v koledarju {calendar}",
    "You restored event {event} of calendar {calendar}" : "Obnovite dogodek {event} v koledarju {calendar}",
    "Busy" : "Zasedeno",
    "Calendar, contacts and tasks" : "Koledar, stiki in naloge",
    "A <strong>calendar</strong> was modified" : "V <strong>koledar</strong> je vpisana sprememba",
    "A calendar <strong>event</strong> was modified" : "Spremenjen je <strong>dogodek</strong> v koledarju",
    "Contact birthdays" : "Obletnice stikov",
    "Death of %s" : "%s (obletnica smrti)",
    "Untitled calendar" : "Neimenovan koledar",
    "Calendar:" : "Koledar:",
    "Date:" : "Datum:",
    "Where:" : "Kje:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n leto","%n leti","%n leta","%n let"],
    "_%n month_::_%n months_" : ["%n mesec","%n meseca","%n meseci","%n mesecev"],
    "_%n day_::_%n days_" : ["%n dan","%n dneva","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n ura","%n uri","%n ure","%n ur"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuti","%n minute","%n minut"],
    "%s (in %s)" : "%s (čez %s)",
    "%s (%s ago)" : "%s (%s nazaj)",
    "Calendar: %s" : "Koledar: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Kje: %s",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Cancelled: %1$s" : "Preklicano: %1$s",
    "Re: %1$s" : "Odg: %1$s",
    "Invitation: %1$s" : "Povabilo: %1$s",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Udeleženci:",
    "Title:" : "Naslov:",
    "Time:" : "Čas:",
    "Location:" : "Mesto:",
    "Link:" : "Povezava:",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "More options …" : "Več možnosti ...",
    "More options at %s" : "Več možnosti je na %s",
    "Contacts" : "Stiki",
    "You deleted address book {addressbook}" : "Izbrišete imenik {addressbook}",
    "File is not updatable: %1$s" : "Datoteke ni mogoče posodobiti: %1$s",
    "Could not write file contents" : "Ni mogoče zapisati vsebine datoteke",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Could not rename part file to final file" : "Ni mogoče preimenovati delne datoteke v končno ime.",
    "Failed to check file size: %1$s" : "Preverjanje velikosti je spodletelo: %1$s",
    "Could not open file" : "Datoteke ni mogoče odpreti",
    "Failed to open file: %1$s" : "Odpiranje datoteke je spodletelo: %1$s",
    "File not found: %1$s" : "Datoteke ni mogoče najti: %1$s",
    "System is in maintenance mode." : "Sistem je v vzdrževalnem načinu.",
    "Upgrade needed" : "Zahtevana je posodobitev",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Za uporabo CalDAV in CardDAV v okoljih iOS/macOS je treba %s nastaviti za uporabo HTTPS.",
    "Configures a CalDAV account" : "Nastavi račun CalDAV",
    "Configures a CardDAV account" : "Nastavi račun CardDAV",
    "Events" : "Dogodki",
    "Tasks" : "Naloge",
    "Untitled task" : "Neimenovana naloga",
    "Completed on %s" : "Končana %s",
    "Due on %s by %s" : "Poteče %s ob %s",
    "Due on %s" : "Poteče %s",
    "Contacts and groups" : "Stiki in skupine",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Končna točka WebDAV",
    "Availability" : "Razpoložljivost",
    "Time zone:" : "Časovni pas:",
    "to" : "do",
    "Delete slot" : "Izbriši možnost",
    "No working hours set" : "Ni navedenih delovnih ur",
    "Add slot" : "Dodaj možnost",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sunday" : "nedelja",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Samodejno nastavi stanje uporabnika na »Ne moti« in zavračaj prikaz obvestil izven časa razpoložljivosti.",
    "Save" : "Shrani",
    "Failed to load availability" : "Nalaganje seznama razpoložljivih polj je spodletelo",
    "Saved availability" : "Čas razpoložljivosti je shranjen",
    "Failed to save availability" : "Shranjevanje časa razpoložljivosti je spodletelo",
    "Calendar server" : "Strežnik koledarja",
    "Send invitations to attendees" : "Pošlji povabilo udeležencem",
    "Automatically generate a birthday calendar" : "Samodejno ustvari koledar rojstnih dni",
    "Birthday calendars will be generated by a background job." : "Koledarji rojstnih dni bodo ustvarjeni in posodabljani v ozadju.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "To pomeni, da ne bodo na voljo takoj po omogočanju, ampak šele po krajšem času.",
    "Send notifications for events" : "Pošlji obvestila za dogodke",
    "Notifications are sent via background jobs, so these must occur often enough." : "Obvestila so poslana samodejno z opravili v ozadju, ker pomeni, da se morajo ta izvajati dovolj pogosto.",
    "Enable notifications for events via push" : "Omogoči potisna obvestila za dogodke",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Namestite tudi {calendarappstoreopen}Koledar{linkclose}, ali pa se povežite z {calendardocopen}namiznim oziroma mobilnim usklajevalnikom ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Prepričajte se, da je {emailopen}poštni strežnik{linkclose} pravilno nastavljen.",
    "There was an error updating your attendance status." : "Prišlo je do napake med posodabljanjem vaše udeležbe.",
    "Please contact the organizer directly." : "Z organizatorjem stopite neposredno v stik.",
    "Are you accepting the invitation?" : "Ali želite sprejeti povabilo?",
    "Tentative" : "Začasno",
    "Your attendance was updated successfully." : "Vaša prisotnost je uspešno posodobljena.",
    "Invitation canceled" : "Povabilo je preklicano",
    "Invitation updated" : "Povabilo je posodobljeno",
    "Invitation" : "Povabilo"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
